@@ -64,13 +64,13 @@ Get or set the name of the L<Rose::DB::Object>-derived class that fronts the for
 
 =item B<make_method PARAMS>
 
-Create an object method used to fetch and/or manipulate objects from foreign tables.  To do this, the C<make_methods()> class method of the L<method_maker_class> is called.  PARAMS are name/value pairs.  Valid PARAMS are:
+Create an object method used to fetch and/or manipulate objects from foreign tables.  To do this, the C<make_methods()> class method of the L<method_maker_class|/method_maker_class> is called.  PARAMS are name/value pairs.  Valid PARAMS are:
 
 =over 4
 
 =item C<options HASHREF>
 
-A reference to a hash of options that will be passed as the first argument to the call to the C<make_methods()> class method of the L<method_maker_class>.  This parameter is required, and the HASHREF must include a value for the key C<target_class>, which C<make_methods()> needs in order to determine where to make the method.
+A reference to a hash of options that will be passed as the first argument to the call to the C<make_methods()> class method of the L<method_maker_class|/method_maker_class>.  This parameter is required, and the HASHREF must include a value for the key C<target_class>, which C<make_methods()> needs in order to determine where to make the method.
 
 =back
 
@@ -94,19 +94,19 @@ The call to C<make_methods()> looks something like this:
 
 where C<$args{'options'}> is the value of the "options" PARAM.
 
-The L<method_maker_class> is expected to be a subclass of (or otherwise conform to the interface of) L<Rose::Object::MakeMethods>.  See the L<Rose::Object::MakeMethods> documentation for more information on the interface, and the C<make_methods()> method in particular.
+The L<method_maker_class|/method_maker_class> is expected to be a subclass of (or otherwise conform to the interface of) L<Rose::Object::MakeMethods>.  See the L<Rose::Object::MakeMethods> documentation for more information on the interface, and the C<make_methods()> method in particular.
 
-More than one method may be created, but there must be at least one method created, and its name must match the L<method_name> (or L<name> if L<method_name> is undefined).
+More than one method may be created, but there must be at least one method created, and its name must match the L<method_name|/method_name> (or L<name|/name> if L<method_name|/method_name> is undefined).
 
 =item B<method_maker_arguments>
 
-Returns a hash (in list context) or a reference to a hash (in scalar context) or arguments that will be passed (as a hash ref) to the call to the C<make_methods()> class method of the L<method_maker_class>, as shown in the L<make_method> example above.
+Returns a hash (in list context) or a reference to a hash (in scalar context) or arguments that will be passed (as a hash ref) to the call to the C<make_methods()> class method of the L<method_maker_class|/method_maker_class>, as shown in the L<make_method|/make_method> example above.
 
-The default implementation populates the hash with the defined return values of the object methods named by L<method_maker_argument_names>.  (Method names that return undefined values are not included in the hash.)
+The default implementation populates the hash with the defined return values of the object methods named by L<method_maker_argument_names|/method_maker_argument_names>.  (Method names that return undefined values are not included in the hash.)
 
 =item B<method_maker_argument_names>
 
-Returns a list of methods to call in order to generate the L<method_maker_arguments> hash.
+Returns a list of methods to call in order to generate the L<method_maker_arguments|/method_maker_arguments> hash.
 
 =item B<method_maker_class>
 
@@ -114,11 +114,11 @@ Returns the name of the L<Rose::Object::MakeMethods>-derived class used to creat
 
 =item B<method_maker_type>
 
-Returns the method type, which is passed to the call to the C<make_methods()> class method of the L<method_maker_class>, as shown in the L<make_method> example above.  You must override this method in your subclass.  The default implementation causes a fatal error if called.
+Returns the method type, which is passed to the call to the C<make_methods()> class method of the L<method_maker_class|/method_maker_class>, as shown in the L<make_method|/make_method> example above.  You must override this method in your subclass.  The default implementation causes a fatal error if called.
 
 =item B<method_name [NAME]>
 
-Get or set the name of the object method to be created for this relationship.  This may be left undefined if the desired method name is stored in L<name> instead.  Once the method is actually created, the L<method_name> will be set.
+Get or set the name of the object method to be created for this relationship.  This may be left undefined if the desired method name is stored in L<name|/name> instead.  Once the method is actually created, the L<method_name|/method_name> will be set.
 
 =item B<name [NAME]>
 
